@@ -29,6 +29,7 @@ Type cDD(objective_function<Type> *obj) {
   DATA_INTEGER(state_space);
   DATA_IVECTOR(use_prior); // Boolean vector, whether to set a prior for R0, h, M, q (length of 3 + nsurvey)
   DATA_MATRIX(prior_dist); // Distribution of priors for R0, h, M, q (rows), columns indicate parameters of distribution calculated in R (see RCM_prior fn)
+  DATA_INTEGER(sim_process_error);
 
   PARAMETER(R0x);
   PARAMETER(transformed_h);
@@ -87,6 +88,8 @@ Type cDD(objective_function<Type> *obj) {
   vector<Type> Rec_dev(ny);
   vector<Type> Binf(ny);
   vector<Type> Ninf(ny);
+  
+  vector<Type> log_rec_dev_sim = log_rec_dev;
 
   //--INITIALIZE
   Type BPReq = cDD_BPR(F_equilibrium, M, wk, Kappa, Winf);
@@ -97,7 +100,13 @@ Type cDD(objective_function<Type> *obj) {
   for(int tt=0;tt<k;tt++) R(tt) = Req;
   if(state_space) {
     Rec_dev(0) = exp(log_rec_dev(0) - 0.5 * tau * tau);
+    SIMULATE if(sim_process_error) {
+      log_rec_dev_sim(0) = rnorm(log_rec_dev(0), tau);
+      Rec_dev(0) = exp(log_rec_dev_sim(0) - 0.5 * tau * tau);
+    }
     R(0) *= Rec_dev(0);
+  } else {
+    Rec_dev.fill(1);
   }
   
   Type Ceqpred = F_equilibrium * B(0);
@@ -127,8 +136,17 @@ Type cDD(objective_function<Type> *obj) {
     }
     if(state_space && tt<ny-1) {
       Rec_dev(tt+1) = exp(log_rec_dev(tt+1) - 0.5 * tau * tau);
+      SIMULATE if(sim_process_error) {
+        log_rec_dev_sim(tt+1) = rnorm(log_rec_dev(tt+1), tau);
+        Rec_dev(tt+1) = exp(log_rec_dev_sim(tt+1) - 0.5 * tau * tau);
+      }
       R(tt+1) *= Rec_dev(tt+1);
     }
+    
+    SIMULATE {
+      C_hist(tt) = Cpred(tt);
+    }
+    
   }
 
   //--ARGUMENTS FOR NLL
@@ -144,8 +162,17 @@ Type cDD(objective_function<Type> *obj) {
       if(LWT(sur) > 0 && !R_IsNA(asDouble(I_hist(tt,sur)))) {
         if(fix_sigma) {
           nll_comp(sur) -= dnorm_(log(I_hist(tt,sur)), log(Ipred(tt,sur)), I_sd(tt,sur), true);
+          
+          SIMULATE {
+            I_hist(tt,sur) = exp(rnorm(log(Ipred(tt,sur)), I_sd(tt,sur)));
+          }
+          
         } else {
           nll_comp(sur) -= dnorm(log(I_hist(tt,sur)), log(Ipred(tt,sur)), sigma, true);
+          
+          SIMULATE {
+            I_hist(tt,sur) = exp(rnorm(log(Ipred(tt,sur)), sigma));
+          }
         }
       }
     }
@@ -155,6 +182,10 @@ Type cDD(objective_function<Type> *obj) {
   for(int tt=0;tt<ny;tt++) {
     if(LWT(nsurvey) > 0 && !R_IsNA(asDouble(MW_hist(tt)))) {
       nll_comp(nsurvey) -= dnorm(log(MW_hist(tt)), log(MWpred(tt)), sigma_W, true);
+      
+      SIMULATE {
+        MW_hist(tt) = exp(rnorm(log(MWpred(tt)), sigma_W));
+      }
     }
   }
   nll_comp(nsurvey) *= LWT(nsurvey);
@@ -163,7 +194,7 @@ Type cDD(objective_function<Type> *obj) {
   }
 
   //Summing individual jnll and penalties
-  prior -= calc_prior(use_prior, prior_dist, R0, h, SR_type == "BH", log_M, q);
+  prior -= calc_prior(use_prior, prior_dist, R0x, h, SR_type == "BH", log_M, q, rescale);
   Type nll = nll_comp.sum() + penalty + prior;
 
   //-------REPORTING-------//
@@ -207,6 +238,13 @@ Type cDD(objective_function<Type> *obj) {
   REPORT(nll_comp);
   REPORT(penalty);
   REPORT(prior);
+  
+  SIMULATE {
+    REPORT(C_hist);
+    REPORT(I_hist);
+    REPORT(MW_hist);
+    REPORT(log_rec_dev_sim);
+  }
 
   return nll;
 }
